aboutsummaryrefslogtreecommitdiff
path: root/benchmark/internal/oblast_pgx/handle.go
diff options
context:
space:
mode:
authorStefan Majewsky <majewsky@gmx.net>2026-07-31 21:39:56 +0200
committerStefan Majewsky <majewsky@gmx.net>2026-07-31 23:35:23 +0200
commit656e5dcce132716b39005814407224f989aa8c2d (patch)
treeab0a6d3a046170f0ace6a6e4ab3668ce0af811ae /benchmark/internal/oblast_pgx/handle.go
parenta2f8d7a68f324d5b4086148571f990409425e22a (diff)
downloadgo-oblast-656e5dcce132716b39005814407224f989aa8c2d.tar.gz
replace types Handle, DB, Conn, Tx with their gg/gsql equivalents
Diffstat (limited to 'benchmark/internal/oblast_pgx/handle.go')
-rw-r--r--benchmark/internal/oblast_pgx/handle.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/benchmark/internal/oblast_pgx/handle.go b/benchmark/internal/oblast_pgx/handle.go
index 845fbe4..4bd72bd 100644
--- a/benchmark/internal/oblast_pgx/handle.go
+++ b/benchmark/internal/oblast_pgx/handle.go
@@ -12,7 +12,7 @@ import (
"github.com/jackc/pgx/v5"
"github.com/jackc/pgx/v5/pgconn"
"github.com/jackc/pgx/v5/pgxpool"
- "go.xyrillian.de/oblast/handle"
+ "go.xyrillian.de/gg/gsql"
)
type Handle interface {
@@ -27,7 +27,7 @@ var (
_ Handle = pgx.Tx(&pgxpool.Tx{})
)
-func Wrap(h Handle) handle.Handle {
+func Wrap(h Handle) gsql.Handle {
switch h := h.(type) {
case *pgx.Conn:
return wrappedHandle{h}
@@ -46,8 +46,8 @@ type wrappedHandle struct {
inner Handle
}
-// OblastPrepare implements the [handle.Handle] interface.
-func (h wrappedHandle) OblastPrepare(ctx context.Context, query string, repeated bool) (handle.Statement, error) {
+// GSQLPrepare implements the [gsql.Handle] interface.
+func (h wrappedHandle) GSQLPrepare(ctx context.Context, query string, repeated bool) (gsql.Statement, error) {
if !repeated {
return wrappedUnpreparedStatement{query, h.inner}, nil
}
@@ -74,7 +74,7 @@ func deallocate(ctx context.Context, h Handle, stmt *pgconn.StatementDescription
case *pgx.Conn:
return h.Deallocate(ctx, stmt.Name)
case *pgxpool.Conn:
- panic("unreachable") // because func OblastPrepare() does not return a wrappedPreparedStatement for this underlying type
+ panic("unreachable") // because func GSQLPrepare() does not return a wrappedPreparedStatement for this underlying type
case pgx.Tx:
return h.Conn().Deallocate(ctx, stmt.Name)
default:
@@ -82,8 +82,8 @@ func deallocate(ctx context.Context, h Handle, stmt *pgconn.StatementDescription
}
}
-// OblastQuery implements the [handle.Handle] interface.
-func (h wrappedHandle) OblastQuery(ctx context.Context, query string, args []any) (handle.Rows, error) {
+// GSQLQuery implements the [gsql.Handle] interface.
+func (h wrappedHandle) GSQLQuery(ctx context.Context, query string, args []any) (gsql.Rows, error) {
rows, err := h.inner.Query(ctx, query, args...)
return wrappedRows{rows}, err
}